@@ -2,6 +2,11 @@ import numpy as np
 
 
 def train(data):
+    """No need for train in this model - just for consistency with other models.
+
+    Args:
+        data (None): Just for consistency with other models.
+    """
     pass
 
 
@@ -10,8 +15,8 @@ def predict(data, model, predicts=7):
 
     Args:
         data (np.ndarray): Time series data.
+        model: None - argument just for consistent call with other models.
         predicts (int, optional): Number of predicted values. Defaults to 7.
-        predicted_column_index (int, optional): If multidimensional, define what column is predicted. Defaults to 0.
 
     Returns:
         np.ndarray: Predictions of input time series.
@@ -21,6 +26,5 @@ def predict(data, model, predicts=7):
     summed = sum(data)
     average = summed / len(data)
     predictions_list = [average] * predicts
-    predictions = np.array(predictions_list)
 
-    return predictions
+    return np.array(predictions_list)
